# Analemma Package API Reference

## Modules

#### [geometry](#geometry)
#### [orbit](#orbit)
#### [plot](#plot)

--------------------------------

<a name="geometry"></a>
## **Module: `geometry`**
::: analemma.geometry

<a name="orbit"></a>
## **Module: `orbit`**
::: analemma.orbit

<a name="plot"></a>
## **Module: `plot`**
::: analemma.plot
